### This demo will use the geomorph and Momocs packages and existing datasets to show a set of simple analyses and visualizations.

###geomorph
install.packages("geomorph")
library(geomorph)

### For the  demo, we will use the geomorph dataset of coordinates for 40 specimens of Plethodon salamanders from two different sites.
data(plethodon) 
summary(plethodon)
### Take a closer look at species and site data
summary(plethodon$species) 
summary(plethodon$site)
plot(plethodon$outline)
### Generalized Procrustes transformation to standardize the data
plethogp <- gpagen(plethodon$land) 
plotAllSpecimens(plethodon$land, links=plethodon$links)
plotAllSpecimens(plethogp$coords, links=plethodon$links)
# Plotting the GP coordinates and the orginal coordinates helps see what the transformation actually does.
summary(plethogp)
### Quite different from regular plethodon 
### Procrustes coordinates are the data used in all further analyses in geomorpho work

plethopca <- plotTangentSpace(plethogp$coords, label=T) 
plethospec <- plotTangentSpace(plethogp$coords, groups=(plethodon$species))
plethosite <- plotTangentSpace(plethogp$coords, groups=(plethodon$site))
gp <- as.factor(paste(plethodon$species, plethodon$site))
plethospec <- plotTangentSpace(plethogp$coords, groups=gp)

plethocon <- apply(plethogp$coords, c(1,2), mean)
plot(plethocon)
for(i in 1:length(plethogp$coords[,,3]))
  points(plethogp$coords[,,i])
points(plethocon, col="green", pch=30)
### This shows the consensus shape plotted amongst the GP coordinates

plotRefToTarget(plethocon, plethogp$coords[,,1])
### You can check thin plate splines for other specimens by changing the [,,#]
### You can also change the magnification of the differences by using mag=#
plotRefToTarget(plethocon, plethogp$coords[,,3], mag=3)

### Plethodon dataset is from the geomorph package. Many thanks to the authors of that package for creating many of the useful (and working) tutorials/presentations out there.

###Momocs

install.packages("Momocs")
library(Momocs)

###lets look at outline data
data(bot)
bot
panel(bot, fac="type", names=TRUE)
class(bot)
str(bot)
guinness <- bot[9]
head(guinness)
stack(bot)
coo_oscillo(bot[9], "efourier")

###Harmonics 
Ptolemy(bot[9])

calibrate_harmonicpower(bot)
calibrate_deviations(bot)
calibrate_reconstructions(bot)

### a PCA object, let's plot it
bot.p <- PCA(bot.f)
class(bot.p)       
plot(bot.p)

###Fun with plots
coo_plot(guinness,main="Raw Guinness")

coo_plot(guinness, col="bisque", border="bisque3", lwd=2, lty=2, main="A Guinness with make-up")

coo_plot(coo_sample(guinness, 40), points=TRUE, main="A 40-points Guinness (curv. abscissa)")

coo_plot(coo_center(guinness) , main="A centered Guinness")
abline(v=0, h=0, lty=2, col="grey80")
coo_plot(coo_template(guinness, size=0.5),
         xlim=c(-0.5, 0.5), ylim=c(-0.5, 0.5), 
         main="A 'templated' Guinness") 
rect(-0.25, -0.25, 0.25, 0.25, col=NA)
coo_plot(coo_trans(guinness, 1e4, 1e4) ,
         main="A (+1000, +1000) translated Guinness")
coo_plot(coo_rotate(guinness, pi/4) , main="A pi/4 rotated Guinness")
coo_plot(coo_smooth(guinness, 500), main="A smoothed Guinness")
coo_plot(coo_slide(guinness, 1329), main="A slided Guinness")
 
### bot dataset is from the Momocs package